<?php


namespace App\Presenters;

use Nette,
	App\Model;
use \Mesour\DataGrid\Grid,
	\Mesour\DataGrid\BasicGrid,
	\Mesour\DataGrid\NetteDbDataSource,
	\Mesour\DataGrid\Components\Link;
use  Nette\Application\UI;
/**
 * Description of Pokus
 *
 * @author Erika
 */
class DotaceUdajePresenter extends UI\Presenter{
      /**
     *
     * @inject 
     * @var \App\Model\MujModel
     */
    public $muj_model;
    
    /*public function renderDefault(){
        $this->template->dotace = $this->muj_model->getTable ('dotace')              
               ->group('firmy.nazev') 
               ->select('firmy.nazev, SUM(cerpana_castka) AS price_sum');
    }*/
    public function renderGraf(){
        $this->template->dotace = $this->muj_model->getTable ('dotace')              
               ->group('firmy.nazev') 
               ->select('firmy.nazev, SUM(cerpana_castka) AS price_sum');
    }
    
    public function createComponentDotaceUdajeGrid($name) {
        $selection = $this->muj_model->getTable('dotace')
                ->select('dotace.id, firmy.nazev,obdobi, cerpana_castka, uvolnena_castka, vracena_castka, poskytovatel');
        $table_id = 'id';        
        $source = new NetteDbDataSource($selection);
        $source->setPrimaryKey($table_id);       
        $grid = new Grid($this, $name);
        $grid->setDataSource($source);  
        $grid->setEmptyText('Tato tabulka je prázdná');        
        $pager_limit = 8; //nastaveni pageru       
        $grid->enablePager($pager_limit);
        $grid->enableFilter($this['dotaceUdajeFilter']);
        $filter_values = $grid->getFilterValues(); 
        if (empty($filter_values) === FALSE) {
		if (isset($filter_values['obdobi']) && !empty($filter_values['obdobi'])) {
			$source->where('obdobi LIKE ?', '%' . $filter_values['obdobi'] . '%');
		}
                if (isset($filter_values['nazev']) && !empty($filter_values['nazev'])) {
			$source->where('Firmy.nazev LIKE ?', '%' . $filter_values['nazev'] . '%');
		}
                if (isset($filter_values['poskytovatel']) && !empty($filter_values['poskytovatel'])) {
			$source->where('poskytovatel LIKE ?', '%' . $filter_values['poskytovatel'] . '%');
		}
	
	}
        $grid->enableEditableCells();
        $grid->onEditCell[]= $this->editColumn;        
        //nastaveni gridu
        $grid->addText('nazev','Firma')->setEditable(FALSE);
        $grid->addText('obdobi','Období');
        $grid->addNumber('uvolnena_castka','Uvolněná částka')->setThousandsSeparator(' ');
        $grid->addNumber('cerpana_castka','Čerpaná částka')->setThousandsSeparator(' ');
        $grid->addNumber('vracena_castka','Vrácená částka')->setThousandsSeparator(' ');
        $grid->addText('poskytovatel','Zdroj dotace');        
        $container = $grid->addContainer('akce', 'Akce')->setOrdering(FALSE);
        $action = $container->addActions('Akce');    
        $action->addButton()
               ->setType('btn-danger')
               ->setIcon('glyphicon-trash')
               ->setConfirm('Opravdu chceš smazat vybranou dotaci?')
               ->addAttribute('href', new Link(array(
                Link::HREF => 'deleteDotace!',
                Link::PARAMS => array( 
                    'id'=>'{'. 'id'. '}' 
                )
            )));        
        return $grid;        
    }
    
    public function createComponentDotaceUdajeFilter(){
        $form = new UI\Form;
        $form->addText('obdobi','obdobi')->setAttribute('placeholder','Období');
        $form->addText('nazev','nazev')->setAttribute('placeholder','Firma'); 
        $form->addText('poskytovatel','zdroj')->setAttribute('placeholder','Zdroj dotace');
        $form->addSubmit('filter','Filter');
        $form->addSubmit('reset','Reset');        
        return $form;
    }
    
    public function handleDeleteDotace($id){
        $this->muj_model->getTable('dotace')->where('id = ?',$id)->delete();
        $this->flashMessage("Informace o dotaci byly smazány.", 'success');
        $this->redirect('this');
    }
    
    public function editColumn($line_id, $column_name, $new_value,$old_value) {
        $this->muj_model->getTable('dotace')->where('id = ?', $line_id)
            ->update(array($column_name=> $new_value));
    }   
    
    public function createComponentEditDotaceForm($name) {
        $form = new Nette\Application\UI\Form;
        $firma = $this->muj_model->findAll()->fetchPairs('id', 'nazev');    
        $form->addSelect('firmy_id', 'Firma:', $firma)
                ->setPrompt('-vyber firmu-')
                ->setRequired('Vyber firmu!');        
        $form->addText('poskytovatel', 'Zdroj dotace:');
        $form->addText('obdobi', 'Období:')
                ->addCondition($form::FILLED)
                ->addRule($form::NUMERIC, 'Období musí být číslo!' )
                ->addRule($form::RANGE, 'Období musí být větší jak rok 2008 a menší jak rok 2050', array(2011,2050));
        $form->addText('uvolnena_castka', 'Uvolněná částka:')
                ->addCondition($form::FILLED)
                ->addRule($form::NUMERIC, 'Uvolněná částka musí být číslo!' );
        $form->addText('cerpana_castka', 'Čerpaná částka:')
                ->addCondition($form::FILLED)
                ->addRule($form::NUMERIC, 'Čerpaná částka musí být číslo!' );
        $form->addText('vracena_castka', 'Vrácená částka:')
                ->addCondition($form::FILLED)
                ->addRule($form::NUMERIC, 'Vrácená částka musí být číslo!' );
        $form->addSubmit('send', 'Uložit')->setAttribute('class', 'btn submit');
        $form->onSuccess[] = array($this, 'editDotaceFormSucceeded');  
        $form->addSubmit('cancel', 'Cancel')->setAttribute('class', 'btn cancel')
            ->setValidationScope(FALSE)
            ->onClick[] = array($this, 'cancelDotace');
        return $form;
    }
    
    public function cancelDotace(){
        $this->redirect('DotaceUdaje:default');
    }

    public function editDotaceFormSucceeded($form, $values){
        $this->muj_model->getTable('dotace')->insert($values);
        $this->flashMessage("Informace o dotaci byla úspěšně vložena.", 'success');
        $this->redirect('DotaceUdaje:default');
    }
}
