<?php

namespace App\Presenters;




use Nette,
	App\Model;
use  Nette\Application\UI;
use \Mesour\DataGrid\Grid,
	\Mesour\DataGrid\BasicGrid,
	\Mesour\DataGrid\NetteDbDataSource,
	\Mesour\DataGrid\Components\Link;

 


/**
 * Ekonomika presenter.
 */
class EkonomikaPresenter extends  UI\Presenter 
{
    /**
     *
     * @inject 
     * @var \App\Model\MujModel
     */
    public $muj_model;
   
    public function createComponentEkonomikaGrafForm(){
        $form = new Nette\Application\UI\Form;
        $firma = $this->muj_model->findAll()->fetchPairs('id', 'nazev');       
        $pole = $this->muj_model->getNazvySloupcu(); 
        $sloupce = array();     
        foreach ($pole as $item){
            $volba = $item["name"];
            if (($volba != "id") && ($volba != "obdobi")&& ($volba != "Firmy_id")) {
                $sloupce[$volba]= $volba;                
            }             
        }   
        
        $form->addSelect('firma_id','Firma',$firma)
                ->setPrompt('-vyber firmu-')
                ->setRequired('Vyber firmu!');
        $form->addSelect('ekonomika_name', 'Parametr')
            ->setItems($sloupce)
            ->setPrompt('-vyber parametr-')
            ->setRequired('Vyber parametr!');
        $form->addSubmit('send', 'Vytvoř graf')->setAttribute('class', 'btn submit');
        $form->setMethod('get');
        $form->onSuccess[] = array($this, 'editEkonomikaGrafFormSucceeded');  
        $form->addSubmit('cancel', 'Cancel')->setAttribute('class', 'btn cancel')
                ->setValidationScope(FALSE)
                ->onClick[] = array($this,'cancelGraf');
        
        return $form;
    }
    
    public function cancelGraf(){
        $this->redirect('Ekonomika:default');
    }
    public function editEkonomikaGrafFormSucceeded($form) {
        $values = $form-> getValues();
        $this->muj_model->setGrafId($values['firma_id']);
        $this->muj_model->setGrafColumn($values['ekonomika_name']);
    }

    public function renderGraf(){
        $data_grafu = $this-> muj_model-> getGrafData();
        $this-> template-> data_grafu = $data_grafu;
        $this-> template-> firma = $data_grafu[0]['nazev'];
        $this-> template-> popis = $this-> muj_model-> getGrafColumn();
    }    
    protected function createComponentEkonomikaGrid($name) {
	$selection = $this->muj_model->getTable('ekonomicke_udaje')->select('ekonomicke_udaje.id, 
            firmy_id,obdobi,firmy.nazev,trzby_z_prodeje_vyrobky_sluzeb,osobni_naklady,celkove_mzdy,
            celkovy_vh,provozni_vh,financni_vh, 
            cizi_zdroje,dhm,uver');
        $source = new NetteDbDataSource($selection); 
        $table_id = 'id';
        $source->setPrimaryKey($table_id);
        $grid = new Grid($this, $name);        
        $grid->setDataSource($source);
        $grid->setEmptyText('Tato tabulka je prázdná');
        $pager_limit=8;  
	$grid->enablePager($pager_limit); //nastaveni pageru a pocet polozek       
        $grid->enableFilter($this['ekonomikaFiltr']);
        $filtrovana = $grid->getFilterValues();        

        //filtr
        if(empty($filtrovana) === FALSE){
            if(isset ($filtrovana['obdobi']) && !empty($filtrovana['obdobi'])){
               $source->where('obdobi LIKE ?','%'.$filtrovana['obdobi'].'%'); 
            }
            if(isset ($filtrovana['nazev']) && !empty($filtrovana['nazev'])){
               $source->where('Firmy.nazev LIKE ?','%'.$filtrovana['nazev'].'%'); 
            }            
        }        
        $grid->enableEditableCells(); //editace
        $grid->onEditCell[]= $this->editColumn;         
        //nastaveni gridu    
        $grid->addText('obdobi', 'Období'); 
        $grid->addText('nazev', 'Firma ')	
                ->setEditable(FALSE);
        $grid->addNumber('trzby_z_prodeje_vyrobky_sluzeb', 'Tržby z prodeje')
             ->setThousandsSeparator(' ');
        $grid->addNumber('osobni_naklady', 'Osobní náklady')
             ->setThousandsSeparator(' ');
        $grid->addNumber('celkove_mzdy', 'Celkové mzdy')
             ->setThousandsSeparator(' ');
        $grid->addNumber('celkovy_vh', 'VH')
             ->setThousandsSeparator(' ');
        $grid->addNumber('provozni_vh', 'Provozní VH')
             ->setThousandsSeparator(' ');
        $grid->addNumber('financni_vh', 'Finanční VH')
             ->setThousandsSeparator(' ');
        $grid->addNumber('uver', 'Úvěr')
             ->setThousandsSeparator(' ');
        $grid->addNumber('cizi_zdroje', 'Cizí zdroje')
             ->setThousandsSeparator(' ');
        $grid->addNumber('dhm', 'DHM')
             ->setThousandsSeparator(' ');       
        $container = $grid->addContainer('akce', 'Akce')
                   ->setOrdering(FALSE);
        $action = $container->addActions('Akce');    
        $action->addButton()
               ->setType('btn-danger')
               ->setIcon('glyphicon-trash')
               ->setConfirm('Opravdu chceš smazat vybraný ekonomický údaj?')
               ->addAttribute('href', new Link(array(
                Link::HREF => 'deleteEkonomika!',
                Link::PARAMS => array( // musí to být array
                    'id'=>'{'. 'id'. '}' 
                )
            )));        
        return $grid;
        
}
    
    public function createComponentEkonomikaFiltr() {
	$form = new UI\Form; 
        $form->addText('obdobi','Období')->setAttribute('placeholder','Období');
        $form->addText('nazev','Firma')->setAttribute('placeholder','Firma');		
        $form->addSubmit('filter','Filter');
        $form->addSubmit('reset','Reset');	
        return $form;
}
    // uprava hodnot   
    public function editColumn($line_id, $column_name, $new_value,$old_value) {
        $this->muj_model->getTable('ekonomicke_udaje')->where('id = ?', $line_id)
                ->update(array($column_name=> $new_value));
    }   

    public function handleDeleteEkonomika($id){
        $this->muj_model->getTable('ekonomicke_udaje')
                ->where('id = ?', $id)->delete();
        $this->flashMessage("Informace o ekonomickým údaji byly smazány.", 'success');
        $this->redirect('this');
    }

    protected function createComponentEditEkonomikaForm(){
        $form = new Nette\Application\UI\Form;
        $firma = $this->muj_model->findAll()->fetchPairs('id', 'nazev');
        $form->addText('obdobi', 'Období:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Období musí být číslo!' )
               ->addRule($form::RANGE, 'Období musí být větší jak rok 2011 a menší jak rok 2050', array(2011,2050));
        $form->addSelect('firmy_id', 'Firma:', $firma)
             ->setPrompt('-vyber firmu-')
             ->setRequired('Vyber firmu!');
        $form->addText('trzby_z_prodeje_vyrobky_sluzeb', 'Tržby z prodeje výrobků a služeb:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Tržby z prodeje výrobků a služeb musí být číslo!' );
        $form->addText('celkovy_vh', 'Celkový VH:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Celkový VH musí být číslo!' );
        $form->addText('provozni_vh', 'Provozní VH:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Provozní VH musí být číslo!' );
        $form->addText('financni_vh', 'Finanční VH:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Finanční VH musí být číslo!' );
        $form->addText('uver', 'Úvěr:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Úvěr musí být číslo!' );
        $form->addText('osobni_naklady', 'Osobní náklady:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Osobní náklady musí být číslo!' );
        $form->addText('celkove_mzdy', 'Celkové mzdy:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Celkové mzdy musí být číslo!' );
        $form->addText('cizi_zdroje', 'Cizí zdroje:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'Cizí zdroje musí být číslo!' );
        $form->addText('dhm', 'DHM:')
               ->addCondition($form::FILLED)
               ->addRule($form::NUMERIC, 'DHM musí být číslo!' );

        $form->addSubmit('send', 'Uložit')->setAttribute('class', 'btn submit');
        $form->onSuccess[] = array($this, 'editEkonomikaFormSucceeded');  
       
        $form->addSubmit('cancel', 'Cancel')->setAttribute('class', 'btn cancel')
            ->setValidationScope(FALSE)
            ->onClick[] = array($this, 'cancelEkonomika');
        return $form;
    }

    public function cancelEkonomika(){
        $this->redirect('Ekonomika:default');
    }

    public function editEkonomikaFormSucceeded($form, $values){
        $this->muj_model->getTable('ekonomicke_udaje')->insert($values);
        $this->flashMessage("Ekonomický údaj byl vložen.", 'success');
        $this->redirect('Ekonomika:default');
    }



    
   
       
                   

 }
    

   



