<?php

namespace App\Presenters;
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

/**
 * Description of ProhraneZakazkyPresenter
 *
 * @author Erika
 */

use Nette,
	App\Model;
use \Mesour\DataGrid\Grid,
	\Mesour\DataGrid\BasicGrid,
	\Mesour\DataGrid\NetteDbDataSource,
	\Mesour\DataGrid\Components\Link;
use  Nette\Application\UI;

class ProhraneZakazkyPresenter extends UI\Presenter{
     /**
     *
     * @inject 
     * @var \App\Model\MujModel
     */
    public $muj_model;
    
    public function renderGraf(){
        $this->template->firmy = $this->muj_model->getTable('prohrane_zakazky')                   
        ->group('firmy.nazev')->select('SUM(cena_vyherce) AS price_sum, firmy.nazev');
    }
    
      
    
    public function createComponentProhraneGrid($name){
        $selection = $this->muj_model->getTable('prohrane_zakazky')
                ->select('prohrane_zakazky.id, obdobi, zadavatel, popis, zdroj_financovani,komentar,
                        cena_mso,cena_vyherce,firmy_id, firmy.nazev');        
        $table_id = 'id';       
        $source = new NetteDbDataSource($selection);
        $source->setPrimaryKey($table_id);       
        $grid = new Grid($this, $name);
        $grid->setDataSource($source);
        $grid->setEmptyText('Tato tabulka je prázdná');
        $grid->enableEditableCells();
        $grid->onEditCell[]= $this->editColumn;        
        $pager_limit = 8;        
        $grid->enablePager($pager_limit);
        $grid->addText('obdobi','Období');
        $grid->addText('zadavatel','Zadavatel');
        $grid->addText('popis','Popis');
        $grid->addText('zdroj_financovani','Zdroj financování');
        $grid->addText('komentar','Komentář');
        $grid->addNumber('cena_mso','Cena MSO')->setThousandsSeparator(' ');        
        $grid->addText('nazev','Firma')   
             ->setEditable(FALSE);
        $grid->addNumber('cena_vyherce','Cena výherce')->setThousandsSeparator(' ');
        $grid->enableFilter($this['prohraneZakazkyFiltr']); //nastaveni komponenty aktivityFiltr
        $filtrovana = $grid->getFilterValues();
        if (empty($filtrovana) === FALSE) {            
            if(isset($filtrovana['obdobi'])&& !empty($filtrovana['obdobi'])){
                 $source->where('obdobi LIKE?', '%'.$filtrovana['obdobi'].'%');            
            } 
            if(isset($filtrovana['zadavatel'])&& !empty($filtrovana['zadavatel'])){
                $source->where('zadavatel LIKE?', '%'.$filtrovana['zadavatel'].'%');          
            } 
            if(isset($filtrovana['nazev'])&& !empty($filtrovana['nazev'])){
                $source->where('Firmy.nazev LIKE?', '%'.$filtrovana['nazev'].'%');          
            }                     
           
        }
        $container = $grid->addContainer('akce', 'Akce')
                   ->setOrdering(FALSE);
        $action = $container->addActions('Akce');
        $action->addButton()
            ->setType('btn-danger')
            ->setIcon('glyphicon-trash')
            ->setConfirm('Opravdu chceš smazat vybranou prohranou zakázku?')
            ->addAttribute('href', new Link(array(
             Link::HREF => 'deleteProhranaZakazka!',
             Link::PARAMS => array( // musí to být array
                 'id'=>'{'. 'id'. '}' 
             )

         )));
        return $grid;
       
    }
    public function createComponentProhraneZakazkyFiltr() {
	$form = new UI\Form; 
        $form->addText('obdobi','Období')->setAttribute('placeholder','Období');
        $form->addText('zadavatel','Zadavatel')->setAttribute('placeholder','Zadavatel');
        $form->addText('nazev','Vyherce')->setAttribute('placeholder','Vyherce');		
        $form->addSubmit('filter','Filter');
        $form->addSubmit('reset','Reset'); 	
        return $form;
    }
        
    public function editColumn($line_id, $column_name, $new_value, $old_value) {
        $this->muj_model->getTable('prohrane_zakazky')->where('id = ?', $line_id)
            ->update(array($column_name=> $new_value));
    }
    
    public function handleDeleteProhranaZakazka($id){
        $this->muj_model->getTable('prohrane_zakazky')->where('id = ?', $id)
                ->delete();
        $this->flashMessage("Informace o prohrané zakázce byly smazány.", 'success');
        $this->redirect('this');
    }
    public function cancelProhraneZakazky(){
         $this->redirect('ProhraneZakazky:default');
    }
    
    public function createComponentEditProhraneZakazkyForm(){
        $form = new Nette\Application\UI\Form;
        $firma = $this->muj_model->findAll()->fetchPairs('id', 'nazev');
        $form->addText('obdobi','Období')
             ->addRule($form::NUMERIC, 'Období musí být číslo!' )
             ->addRule($form::RANGE, 'Období musí být větší jak rok 2011 a menší jak rok 2050', array(2011,2050));
        $form->addText('zadavatel', 'Zadavatel:');
        $form->addTextArea('popis', 'Popis:')->setAttribute('cols', 50)
           ->setAttribute('rows', 4);
        $form->addText('zdroj_financovani', 'Zdroj financování:');
        $form->addTextArea('komentar','Komentář')->setAttribute('cols', 50)
           ->setAttribute('rows', 4);
        $form->addText('cena_mso','Cena MSO:')
             ->addRule($form::NUMERIC, 'Cena MSO musí být číslo!' );   
        $form->addSelect('firmy_id', 'Firma', $firma)
             ->setPrompt('-vyber firmu-')
             ->setRequired('Vyber firmu!');
        $form->addText('cena_vyherce','Cena výherce:')
             ->addRule($form::NUMERIC, 'Cena výherce musí být číslo!' );
        $form->addSubmit('send', 'Uložit')->setAttribute('class','btn submit');
        $form->onSuccess[] = array($this, 'editProhraneZakazkyFormSucceeded');  

        $form->addSubmit('cancel', 'Cancel')->setAttribute('class','btn cancel')
            ->setValidationScope(FALSE)
            ->onClick[] = array($this, 'cancelProhraneZakazky');
        return $form;      
        
    }
    
    public function editProhraneZakazkyFormSucceeded($form, $values){
       $this->muj_model->getTable('prohrane_zakazky')->insert($values);       
       $this->flashMessage("Prohraná zakázka byla vložena.",'success');     
       $this->redirect('ProhraneZakazky:default'); 
    }
    
    public function cancelProhaneZakazky(){
        $this->redirect('ProhraneZakazky:default');
        
    }
}
